Module blaxel.core.sandbox.client.models.subdirectory
=====================================================

Classes
-------

`Subdirectory(name: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, path: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>)`
:   Attributes:
        name (Union[Unset, str]):
        path (Union[Unset, str]):
    
    Method generated by attrs for class Subdirectory.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `name: blaxel.core.sandbox.client.types.Unset | str`
    :

    `path: blaxel.core.sandbox.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :